# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "%d min verbleiben zum Lesen",
    "(active)": "(aktiv)",
    "Also available in:": "Auch verfügbar in:",
    "Archive": "Archiv",
    "Atom feed": "Atom-Feed",
    "Authors": "Autoren",
    "Categories": "Kategorien",
    "Comments": "Kommentare",
    "LANGUAGE": "Deutsch",
    "Languages:": "Sprachen:",
    "More posts about %s": "Weitere Einträge über %s",
    "Newer posts": "Neuere Einträge",
    "Next post": "Nächster Eintrag",
    "Next": "Nächster Eintrag",
    "No posts found.": "Keine Einträge gefunden.",
    "Nothing found.": "Nichts gefunden.",
    "Older posts": "Ältere Einträge",
    "Original site": "Original-Seite",
    "Posted:": "Veröffentlicht:",
    "Posts about %s": "Einträge über %s",
    "Posts by %s": "Einträge von %s",
    "Posts for year %s": "Einträge aus dem Jahr %s",
    "Posts for {month_day_year}": "Einträge vom {month_day_year}",
    "Posts for {month_year}": "Einträge aus {month_year}",
    "Previous post": "Vorheriger Eintrag",
    "Previous": "Vorheriger Eintrag",
    "Publication date": "Veröffentlichungsdatum",
    "RSS feed": "RSS-Feed",
    "Read in English": "Auf Deutsch lesen",
    "Read more": "Weiterlesen",
    "Skip to main content": "Springe zum Hauptinhalt",
    "Source": "Source",
    "Subcategories:": "Unterkategorien:",
    "Tags and Categories": "Tags und Kategorien",
    "Tags": "Tags",
    "Toggle navigation": "Navigation umschalten",
    "Uncategorized": "Nicht kategorisiert",
    "Up": "Nach oben",
    "Updates": "Updates",
    "Write your page here.": "Schreibe hier deinen Seiteninhalt hin.",
    "Write your post here.": "Schreibe hier deinen Eintrag hin.",
    "old posts, page %d": "Ältere Einträge, Seite %d",
    "page %d": "Seite %d",
    "updated": "aktualisiert",
}
