# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "%d min rămase pentru citire",
    "(active)": "(activ)",
    "Also available in:": "Valabil și în:",
    "Archive": "Arhivă",
    "Atom feed": "Atom flux",
    "Authors": "Autori",
    "Categories": "Categorii",
    "Comments": "Comentarii",
    "LANGUAGE": "Română",
    "Languages:": "Traducere:",
    "More posts about %s": "Mai multe articole despre %s",
    "Newer posts": "Articole recente",
    "Next post": "Următorul articol",
    "Next": "Următorul",
    "No posts found.": "Nici un articol găsit.",
    "Nothing found.": "Nimic găsit.",
    "Older posts": "Articole vechi",
    "Original site": "Pagină originală",
    "Posted:": "Postat:",
    "Posts about %s": "Articole despre %s",
    "Posts by %s": "Articole de %s",
    "Posts for year %s": "Articolele pentru anul %s",
    "Posts for {month_day_year}": "Articole din  {month_day_year}",
    "Posts for {month_year}": "Articole din {month_year}",
    "Previous post": "Articole anterioare",
    "Previous": "Anterior",
    "Publication date": "Data publicației",
    "RSS feed": "RSS flux",
    "Read in English": "Citește în Română",
    "Read more": "Citește mai mult",
    "Skip to main content": "Sări la conținutul principal",
    "Source": "Sursă",
    "Subcategories:": "Subcategorii:",
    "Tags and Categories": "Etichete și Categorii",
    "Tags": "Etichete",
    "Toggle navigation": "Activează navigația",
    "Uncategorized": "Necategorizat",
    "Up": "Sus",
    "Updates": "Actualizări",
    "Write your page here.": "Scrie-ți pagina aici.",
    "Write your post here.": "Scrie-ți articolul aici.",
    "old posts, page %d": "articole vechi, pagina %d",
    "page %d": "pagina %d",
    "updated": "actualizat",
}
